@@ -46,6 +46,29 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>DialogComment</name>
+    <message>
+        <location filename="DialogComment.py" line="50"/>
+        <source>QNetMan (Comment)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="DialogComment.py" line="51"/>
+        <source>Comment:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="DialogComment.py" line="52"/>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="DialogComment.py" line="53"/>
+        <source>Delete</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>DialogDBStat</name>
     <message>
@@ -233,50 +256,55 @@ record</source>
 <context>
     <name>ListSessions</name>
     <message>
-        <location filename="ListSessions.py" line="87"/>
+        <location filename="ListSessions.py" line="89"/>
         <source>QNetMan (Networking sessions)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessions.py" line="88"/>
+        <location filename="ListSessions.py" line="90"/>
         <source>View</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessions.py" line="89"/>
+        <location filename="ListSessions.py" line="91"/>
         <source>Filter</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessions.py" line="90"/>
+        <location filename="ListSessions.py" line="92"/>
         <source>Select all</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessions.py" line="91"/>
+        <location filename="ListSessions.py" line="93"/>
         <source>Delete</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessions.py" line="92"/>
+        <location filename="ListSessions.py" line="94"/>
         <source>Menu</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessions.py" line="93"/>
+        <location filename="ListSessions.py" line="95"/>
         <source>Database statistics</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessions.py" line="94"/>
+        <location filename="ListSessions.py" line="96"/>
         <source>Clean database</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessions.py" line="95"/>
+        <location filename="ListSessions.py" line="97"/>
         <source>Calculate traffic</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="ListSessions.py" line="98"/>
+        <source>Comment</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ListSessionsExt</name>
@@ -291,57 +319,57 @@ record</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="170"/>
+        <location filename="ListSessionsExt.py" line="172"/>
         <source>Session full time:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="264"/>
+        <location filename="ListSessionsExt.py" line="266"/>
         <source>Warning</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="265"/>
+        <location filename="ListSessionsExt.py" line="267"/>
         <source>Session does not contain data</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="323"/>
+        <location filename="ListSessionsExt.py" line="324"/>
         <source>records</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="126"/>
+        <location filename="ListSessionsExt.py" line="128"/>
         <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="127"/>
+        <location filename="ListSessionsExt.py" line="129"/>
         <source>Sorry, an error in the database.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="361"/>
+        <location filename="ListSessionsExt.py" line="362"/>
         <source>Select a session to calculate the traffic</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="366"/>
+        <location filename="ListSessionsExt.py" line="367"/>
         <source>Sessions:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="369"/>
+        <location filename="ListSessionsExt.py" line="370"/>
         <source>Full traffic:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="367"/>
+        <location filename="ListSessionsExt.py" line="368"/>
         <source>RX bytes:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ListSessionsExt.py" line="368"/>
+        <location filename="ListSessionsExt.py" line="369"/>
         <source>TX bytes:</source>
         <translation type="unfinished"></translation>
     </message>
@@ -371,7 +399,7 @@ connections</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="225"/>
+        <location filename="ViewSession.py" line="235"/>
         <source>Menu</source>
         <translation type="unfinished"></translation>
     </message>
@@ -566,62 +594,62 @@ connections</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="204"/>
+        <location filename="ViewSession.py" line="214"/>
         <source>QNetMan (Sessions)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="205"/>
+        <location filename="ViewSession.py" line="215"/>
         <source>Session start time:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="206"/>
+        <location filename="ViewSession.py" line="216"/>
         <source>Session end time:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="208"/>
+        <location filename="ViewSession.py" line="218"/>
         <source>2000-01-01 00:00:00</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="217"/>
+        <location filename="ViewSession.py" line="227"/>
         <source>RX:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="212"/>
+        <location filename="ViewSession.py" line="222"/>
         <source>0000.00 MB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="218"/>
+        <location filename="ViewSession.py" line="228"/>
         <source>TX:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="213"/>
+        <location filename="ViewSession.py" line="223"/>
         <source>Session full time:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="214"/>
+        <location filename="ViewSession.py" line="224"/>
         <source>00 h; 00 m; 00 s</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="215"/>
+        <location filename="ViewSession.py" line="225"/>
         <source>Full session traffic :</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="216"/>
+        <location filename="ViewSession.py" line="226"/>
         <source>000000 MB</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="226"/>
+        <location filename="ViewSession.py" line="236"/>
         <source>Remove session</source>
         <translation type="unfinished"></translation>
     </message>
@@ -716,7 +744,7 @@ connections</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="223"/>
+        <location filename="ViewSession.py" line="233"/>
         <source>000 kB/s</source>
         <translation type="unfinished"></translation>
     </message>
@@ -726,7 +754,7 @@ connections</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSession.py" line="224"/>
+        <location filename="ViewSession.py" line="234"/>
         <source>Please, wait ...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -734,38 +762,38 @@ connections</source>
 <context>
     <name>MainWindowExt</name>
     <message>
-        <location filename="MainWindowExt.py" line="36"/>
+        <location filename="MainWindowExt.py" line="37"/>
         <source>Daemon QNetMan is not running.
 Start daemons now ?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="37"/>
+        <location filename="MainWindowExt.py" line="38"/>
         <source>Warning</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="42"/>
+        <location filename="MainWindowExt.py" line="43"/>
         <source>Information</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="43"/>
+        <location filename="MainWindowExt.py" line="44"/>
         <source>Please restart the program now.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="46"/>
+        <location filename="MainWindowExt.py" line="47"/>
         <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="47"/>
+        <location filename="MainWindowExt.py" line="48"/>
         <source>Failed to start daemon.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="MainWindowExt.py" line="50"/>
+        <location filename="MainWindowExt.py" line="51"/>
         <source>Features will be limited.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -859,22 +887,22 @@ Start daemons now ?</source>
 <context>
     <name>ViewCurrentSessionExt</name>
     <message>
-        <location filename="ViewCurrentSessionExt.py" line="501"/>
+        <location filename="ViewCurrentSessionExt.py" line="516"/>
         <source>Refresh interval:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSessionExt.py" line="502"/>
+        <location filename="ViewCurrentSessionExt.py" line="517"/>
         <source>sec</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSessionExt.py" line="631"/>
+        <location filename="ViewCurrentSessionExt.py" line="646"/>
         <source>Selected network interface:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewCurrentSessionExt.py" line="674"/>
+        <location filename="ViewCurrentSessionExt.py" line="690"/>
         <source>Recording...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -882,20 +910,35 @@ Start daemons now ?</source>
 <context>
     <name>ViewSessionExt</name>
     <message>
-        <location filename="ViewSessionExt.py" line="206"/>
+        <location filename="ViewSessionExt.py" line="212"/>
         <source>h</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSessionExt.py" line="207"/>
+        <location filename="ViewSessionExt.py" line="213"/>
         <source>m</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="ViewSessionExt.py" line="208"/>
+        <location filename="ViewSessionExt.py" line="214"/>
         <source>s</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <location filename="ViewSessionExt.py" line="586"/>
+        <source>Comment on the session is saved</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="ViewSessionExt.py" line="590"/>
+        <source>Comment on the session is removed</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="ViewSessionExt.py" line="594"/>
+        <source>Comment write error</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>WinAboutExt</name>
