@@ -116,6 +116,8 @@ class ListSessionsExt( QtGui.QMainWindow ):
 				stop_t = self.listSessionItems[j]["stop"]
 				ok = self.db.cleanDBbyTime( start_t, stop_t )
 				if ok == True:
+					# удаляем комментарии к выделенным сессиям (foreign_keys не работает, сука) XXX
+					self.db.delCommentSession( self.listSessionItems[j]["session_id"] )
 					#удаляем из списка
 					self.ui.listWidgetSessions.takeItem( j )
 					del item
@@ -273,7 +275,7 @@ class ListSessionsExt( QtGui.QMainWindow ):
 			buf[0]["type_session"] = el0["type_session"]
 			buf[1] = el0
 			
-		self.mwViewSession = ViewSessionExt( self, self.db, self.qset, self.currentSelectedItem.text(), buf )
+		self.mwViewSession = ViewSessionExt( self, self.db, self.qset, self.currentSelectedItem.text(), buf, self.listSessionItems[row]["session_id"] )
 		self.mwViewSession.show()
 		self.mwViewSession.setTimeSession( allSeconds, h, m, s )
 		self.mwViewSession.showData()
