@@ -14,7 +14,8 @@ import QNMSettings
 from mydb import MyDB
 
 class MainWindowExt( QtGui.QMainWindow ):
-	def __init__(self, splash, parent = None):
+	#pvr# def __init__(self, splash, parent = None):
+	def __init__(self, parent = None):
 		QtGui.QMainWindow.__init__( self, parent )
 		self.parent = parent
 		
@@ -30,8 +31,8 @@ class MainWindowExt( QtGui.QMainWindow ):
 		self.mydbus = QNMDBusClient()
 		retVal = self.mydbus.connectDBus()
 		if retVal == False:
-			splash.finish(self)
-			splash.finish(self)
+			#splash.finish(self)
+			#splash.finish(self)
 			txt = QtGui.QApplication.translate("MainWindowExt", "Daemon QNetMan is not running.\nStart daemons now ?", None, QtGui.QApplication.UnicodeUTF8)
 			txt_w = QtGui.QApplication.translate("MainWindowExt", "Warning", None, QtGui.QApplication.UnicodeUTF8)
 			r = QtGui.QMessageBox.question(self, txt_w, txt, QtGui.QMessageBox.Ok, QtGui.QMessageBox.Cancel)
@@ -70,7 +71,7 @@ class MainWindowExt( QtGui.QMainWindow ):
 
 		self.actionForm()
 
-		splash.finish(self)
+		#splash.finish(self)
 		
 
 	def actionForm(self):
