@@ -8,18 +8,19 @@ import myconfig
 from mydb import MyDB
 
 class OptionsWindowExt( QtGui.QMainWindow ):
-	def __init__(self, parent, mydbus ):
+	def __init__(self, parent, mydb, mydbus ):
 		QtGui.QMainWindow.__init__(self, parent)
 		
 		self.mydbus = mydbus
 
 		try:
 			self.setAttribute( QtCore.Qt.WA_Maemo5StackedWindow )
+			self.setAttribute( QtCore.Qt.WA_Maemo5ShowProgressIndicator )
 		except Exception, e:
 			pass
 			#print "OptionsWindowExt::__init__(): Exception setAttribute(): ", e
 		
-		self.db = MyDB( myconfig.file_db )
+		self.db = mydb
 
 		self.ui = OptionsWindow.Ui_MainWindow()
 		self.ui.setupUi( self )
