@@ -12,6 +12,7 @@ class QNMDBusClient:
 	def __init__(self):
 		self.bus = dbus.SessionBus()
 		self.iface = None
+		self.remote_object = None
 
 	def connectDBus(self):
 		retVal = True
@@ -20,23 +21,25 @@ class QNMDBusClient:
 			remote_object = self.bus.get_object( "com.qnetman.Daemon", "/QNetManDBus" )
 			#Get the remote interface for the remote object
 			self.iface = dbus.Interface( remote_object, "com.qnetman.Daemon" )
+			self.remote_object = remote_object
 		except dbus.DBusException, e:
 			print "QNetManDBus::connectDBus(): Except: %s"%e
 			#print_exc()
 			retVal = False
 		return retVal
 	
-	def connectAllSignalDaemon(self):
-		self.iface.connect_to_signal("recordStoped", self.handlerSigRecStoped)
-		self.iface.connect_to_signal("recordStoped", self.handlerSigRecStoped)
 
-
-	def handlerSigRecStoped(self):
-		pass
-	
-		
-	def handlerSigRecStarted(self):
-		pass
+#	def connectAllSignalDaemon(self):
+#		self.iface.connect_to_signal("recStoped", self.handlerSigRecStoped)
+#		self.iface.connect_to_signal("recStarted", self.handlerSigRecStarted)
+#
+#	
+#	def handlerSigRecStoped(self, iface):
+#		print "parent: handlerSigRecStoped(): %s"%iface
+#	
+#		
+#	def handlerSigRecStarted(self, iface):
+#		print "parent: handlerSigRecStarted(): %s"%iface
 	
 
 	def recStart(self, network_iface):
