@@ -11,12 +11,14 @@ from sys import path
 
 #import myconfig
 #from mydb import MyDB
+from MyNotify import MyNotify
 
 from MyGraphicsScene import MyGraphicsScene
 import ViewSessionOptions
+import DialogCommentExt
 
 class ViewSessionExt( QtGui.QMainWindow ):
-	def __init__(self, parent, db, qset, title, buffSessionTraff ):
+	def __init__(self, parent, db, qset, title, buffSessionTraff, session_id ):
 		QtGui.QMainWindow.__init__(self, parent)
 				
 		#массив всех данных трафика за сессию
@@ -34,6 +36,7 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		self.ui = ViewSession.Ui_MainWindow()
 		self.ui.setupUi( self )
 
+		self.noti = MyNotify()
 		#self.setWindowTitle( title )
 
 		#геомертические параметры отображаемого графика
@@ -83,9 +86,10 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		#ширина линии графика (пиксель)
 		self.pxLenGraph = 0
 
-		#соединение с БД
+		#внешние установки
 		self.db = db
 		self.qset = qset
+		self.session_id = session_id
 
 		#цвета графиков
 		rgbRX, rgbTX = self.db.optGetColor()
@@ -114,6 +118,8 @@ class ViewSessionExt( QtGui.QMainWindow ):
 
 	def actionForm(self):
 		self.ui.pBshowOptins.clicked.connect( self.dialogSessionOptions )
+
+		self.ui.pBdialogComment.clicked.connect( self.dlgComment )
 		
 		self.ui.pBzoomIn.clicked.connect( self.zoomIn )
 		self.ui.pBzoomOut.clicked.connect( self.zoomOut )
@@ -563,3 +569,26 @@ class ViewSessionExt( QtGui.QMainWindow ):
 		self.timestamp = (int)(value)
 		self.drawGraph()
 		self.ui_dlgMO.sbTimestamp.setEnabled( True )
+	
+	
+	#------- Dialog comment ----------#
+	def dlgComment(self):
+		self.dlgCom = QtGui.QDialog()
+		self.ui_dlgCom = DialogCommentExt.DialogCommentExt( self.dlgCom, self.db, self.session_id )
+		self.ui_dlgCom.commentAdd.connect( self.slotAddComment )
+		self.ui_dlgCom.commentDel.connect( self.slotDelComment )
+		self.ui_dlgCom.commentFailed.connect( self.slotFailComment )
+		self.dlgCom.show()
+		self.dlgCom.exec_()
+
+	def slotAddComment( self ):
+		txt = QtGui.QApplication.translate("ViewSessionExt", "Comment on the session is saved", None, QtGui.QApplication.UnicodeUTF8)
+		self.noti.notify( txt )
+
+	def slotDelComment( self ):
+		txt = QtGui.QApplication.translate("ViewSessionExt", "Comment on the session is removed", None, QtGui.QApplication.UnicodeUTF8)
+		self.noti.notify( txt )
+	
+	def slotFailComment( self ):
+		txt = QtGui.QApplication.translate("ViewSessionExt", "Comment write error", None, QtGui.QApplication.UnicodeUTF8)
+		self.noti.notify( txt )
