@@ -19,10 +19,10 @@ if __name__ == "__main__":
 	
 	app = QtGui.QApplication( argv )
 	
-	pxm = QtGui.QPixmap(":/splash/pictures/splash.png")
-	splash = QtGui.QSplashScreen(pxm)
-	splash.show()
-	app.processEvents()
+	#pxm = QtGui.QPixmap(":/splash/pictures/splash.png")
+	#splash = QtGui.QSplashScreen(pxm)
+	#splash.show()
+	#app.processEvents()
 
 	trans = QtCore.QTranslator()
 
@@ -32,7 +32,8 @@ if __name__ == "__main__":
 		trans.load( myconfig.i18n_rus )
 		app.installTranslator( trans )
 	
-	ui = MainWindowExt.MainWindowExt( splash )
+	#ui = MainWindowExt.MainWindowExt( splash )
+	ui = MainWindowExt.MainWindowExt()
 
 	ui.show()
 
